#
# spec file for package python-django-allauth
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-django-allauth
Version:        0.42.0
Release:        bp155.2.11
Summary:        Django authentication, registration, account management
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pennersr/django-allauth
Source:         https://files.pythonhosted.org/packages/source/d/django-allauth/django-allauth-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.0
Requires:       python-python3-openid >= 3.0.8
Requires:       python-requests
Requires:       python-requests-oauthlib >= 0.3.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.0}
BuildRequires:  %{python_module python3-openid >= 3.0.8}
BuildRequires:  %{python_module requests-oauthlib >= 0.3.0}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
Integrated set of Django applications addressing authentication, registration,
account management as well as 3rd party (social) account authentication.

%prep
%setup -q -n django-allauth-%{version}
# Five errors reported at https://github.com/pennersr/django-allauth/issues/2210
# Cern provider test module fails
rm allauth/socialaccount/providers/cern/tests.py

# 2 tests failing with KeyError: 'location' (not in response headers)
sed -i 's/test_login/_test_login/' allauth/socialaccount/providers/openid/tests.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=.
%python_expand django-admin-%{$python_bin_suffix} test --settings=test_settings

%files %{python_files}
%doc AUTHORS ChangeLog.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 0.42.0
  * New providers: EDX, Yandex, Mixer.
  * Fixed Twitch get_avatar_url()
  * The Facebook API version now defaults to v7.0.
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.41.0:
  * Fixes CVE-2019-19844: Potential account hijack via password reset form
  bsc#1159447
  * Dropped Python 2 and Django 1 compatibility.
- Do not bother with the lang subpkg as it is needed to have languages
  to be present always anyway
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.40.0:
  * The instagram provider now extracts the user's full name.
  * New provider: NextCloud (OAuth2)
  * Added an SDK_URL setting for customizing the loading of the Facebook JavaScript SDK.
  * Updated Twitch provider to use new authentication endpoints (https://id.twitch.tv) over deprecated v5 endpoints (https://api.twitch.tv/kraken)
  * Added support for Patreon API v2, with API v1 set as default for backwards compatibility.
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Use %%ifpython2/3 to allow building only one flavour
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.39.1:
  * The linkedin_oauth2 provider now gracefully deals with old V1 data that might still be present in SocialAccount.extra_data.
  * New providers: JupyterHub (OAuth2), Steam (OpenID)
  * Refactor translations: Portuguese (Portugal).
  * Add testing for Django 2.2 (no code changes required)
  * linkedin_oauth2: As the LinkedIn V1 API is deprecated, the user info endpoint has been moved over to use the API V2. The format of the user extra_data is different and the profile picture is absent by default.
* Sun Feb 17 2019 John Vandenberg <jayvdb@gmail.com>
- Skip five failing tests
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.38.0
